%% set inputs for solution below
%  The program produces responses to the shocks selected below under
%  irfshock. Paths for all the endogenous variables in the model selected
%  are produced. VariableName_difference holds the piece-wise linear solution for
%  VariableName.  VariableName_uncdifference holds the linear solution for
%  VariableName.

clear 

setpathdynare4
global M_ oo_


modnam = 'eggtrade_potential';
modnamstar = 'eggtrade_potential_zlb';

constraint = 'rs<-(pibar/betap-1)';
constraint_relax ='rs>-(pibar/betap-1)';

% Pick innovation for IRFs
irfshock =char('errconshkpf'); % label for innovation for IRFs

SHOCKS = -0.042916092518532*[4]; 

maxiter = 20;
tol0 = 1e-6;

nperiods = 40;



% Solve nonlinear model
shockssequence = SHOCKS;

betap = 0.9995;  
pibar = 1.00+0.3/400;
etamc     = .75;
etami     = .75;
indexp    = 0.745;
indexw    = 0.745;
empty_var = [];
% list here any parameters to be overwritten -- leave only empty_var for all
% parameters at their default values specified in eggtrade_potential_param
save param_overwrite empty_var betap pibar etamc etami indexp indexw

% Solve model, generate model IRFs
[zdatalinear zdatapiecewise zdatass oobase_ Mbase_  ] = ...
  solve_one_constraint(modnam,modnamstar,...
  constraint, constraint_relax,...
  shockssequence,irfshock,nperiods);


% unpack 
for i=1:M_.endo_nbr
    eval([deblank(M_.endo_names(i,:)),'_u1=zdatalinear(:,i);']);
    eval([deblank(M_.endo_names(i,:)),'_p1=zdatapiecewise(:,i);']);
    eval([deblank(M_.endo_names(i,:)),'_ss1=zdatass(i);']);
end

betap = 0.9995;  
pibar = 1.00+0.3/400;
etamc     = 1.25000;
etami     = 1.25000;
empty_var = [];
% list here any parameters to be overwritten -- leave only empty_var for all
% parameters at their default values specified in eggtrade_potential_param
save param_overwrite empty_var betap pibar etamc etami indexp indexw

% Solve model, generate model IRFs
[zdatalinear zdatapiecewise zdatass oobase_ Mbase_  ] = ...
  solve_one_constraint(modnam,modnamstar,...
  constraint, constraint_relax,...
  shockssequence,irfshock,nperiods);


% unpack 
for i=1:M_.endo_nbr
    eval([deblank(M_.endo_names(i,:)),'_u2=zdatalinear(:,i);']);
    eval([deblank(M_.endo_names(i,:)),'_p2=zdatapiecewise(:,i);']);
    eval([deblank(M_.endo_names(i,:)),'_ss2=zdatass(i);']);
end

betap = 0.9995;  
pibar = 1.00+0.3/400;
etamc     = 2;
etami     = 2;
empty_var = [];
% list here any parameters to be overwritten -- leave only empty_var for all
% parameters at their default values specified in eggtrade_potential_param
save param_overwrite empty_var betap pibar etamc etami indexp indexw

% Solve model, generate model IRFs
[zdatalinear zdatapiecewise zdatass oobase_ Mbase_  ] = ...
  solve_one_constraint(modnam,modnamstar,...
  constraint, constraint_relax,...
  shockssequence,irfshock,nperiods);


% unpack 
for i=1:M_.endo_nbr
    eval([deblank(M_.endo_names(i,:)),'_u3=zdatalinear(:,i);']);
    eval([deblank(M_.endo_names(i,:)),'_p3=zdatapiecewise(:,i);']);
    eval([deblank(M_.endo_names(i,:)),'_ss3=zdatass(i);']);
end


%% Modify to plot IRFs and decision rules

eggtrade_potential_param
eggtrade_potential_comp_param

% plot of experiment
figtitle = '';
legendlist = char('Trade Elasticity 0.75','Trade Elasticity 1.25','Trade Elasticity 2');
titlelist = char('Home GDP','Foreign GDP',...
                 'Home Policy Rate (level, AR)','Home Absorption',...
                 'Home Real Interest Rate (level, AR)','Home Exports',...
                 'Real Exchange Rate','Home Trade Balance (GDP share)');
             
yaxislabels = char('% dev. from s.s.','% dev. from s.s.',...
                   'Percent','Percent',...
                   'Percent','% dev. from s.s.',...
                   '% dev. from s.s.','% dev. from s.s.');
startperiod = 1;
plotperiods = nperiods;
               
line1 = 100*[gdp_p1(startperiod:plotperiods),gdpf_p1(startperiod:plotperiods),...
     (rs_p1(startperiod:plotperiods)+(1/betap*pibar-1))*4,prabs_p1(startperiod:plotperiods),...
     (rs1_p1(startperiod:plotperiods)+(1/betap-1))*4,mgsnif_p1(startperiod:plotperiods),...
     rerpq_p1(startperiod:plotperiods),ntby_p1(startperiod:plotperiods)];
 
line2 = 100*[gdp_p2(startperiod:plotperiods),gdpf_p2(startperiod:plotperiods),...
     (rs_p2(startperiod:plotperiods)+(1/betap*pibar-1))*4,prabs_p2(startperiod:plotperiods),...
     (rs1_p2(startperiod:plotperiods)+(1/betap-1))*4,mgsnif_p2(startperiod:plotperiods),...
     rerpq_p2(startperiod:plotperiods),ntby_p2(startperiod:plotperiods)];
 
line3 = 100*[gdp_p3(startperiod:plotperiods),gdpf_p3(startperiod:plotperiods),...
     (rs_p3(startperiod:plotperiods)+(1/betap*pibar-1))*4,prabs_p3(startperiod:plotperiods),...
     (rs1_p3(startperiod:plotperiods)+(1/betap-1))*4,mgsnif_p3(startperiod:plotperiods),...
     rerpq_p3(startperiod:plotperiods),ntby_p3(startperiod:plotperiods)];
 
makechart_neworder(titlelist,legendlist,figtitle,yaxislabels,line1,line2,line3)

%%

legendlist = char('Trade Elasticity 0.75','Trade Elasticity 1.25','Trade Elasticity 2');
titlelist = char('Home GDP','Home GDP',...
                 'Home Absorption','Home Absorption',...
                 'Home Exports (GDP share)','Home Exports (GDP share)',...
                 'Home Policy Rate (level, AR)','Home Policy Rate (level, AR)');

dev = '% dev. from baseline';
ppt = 'P.p. dev. from baseline';
level = 'Percent';

yaxislabels = char(dev,dev,...
                   dev,dev,...
                   ppt,ppt,...
                   level,level);

line1 = 100*[gdp_u1(startperiod:plotperiods),gdp_p1(startperiod:plotperiods),...
             prabs_u1(startperiod:plotperiods),prabs_p1(startperiod:plotperiods),...
             shrmc*(rpxpq_u1(startperiod:plotperiods)+mgsnif_u1(startperiod:plotperiods)-gdp_u1(startperiod:plotperiods)),shrmc*(rpxpq_p1(startperiod:plotperiods)+mgsnif_p1(startperiod:plotperiods)-gdp_p1(startperiod:plotperiods)),...
             (rs_u1(startperiod:plotperiods)+(pibar/betap-1))*4,(rs_p1(startperiod:plotperiods)+(pibar/betap-1))*4];

line2 = 100*[gdp_u2(startperiod:plotperiods),gdp_p2(startperiod:plotperiods),...
             prabs_u2(startperiod:plotperiods),prabs_p2(startperiod:plotperiods),...
             shrmc*(rpxpq_u2(startperiod:plotperiods)+mgsnif_u2(startperiod:plotperiods)-gdp_u2(startperiod:plotperiods)),shrmc*(rpxpq_p2(startperiod:plotperiods)+mgsnif_p2(startperiod:plotperiods)-gdp_p2(startperiod:plotperiods)),...
             (rs_u2(startperiod:plotperiods)+(pibar/betap-1))*4,(rs_p2(startperiod:plotperiods)+(pibar/betap-1))*4];

line3 = 100*[gdp_u3(startperiod:plotperiods),gdp_p3(startperiod:plotperiods),...
             prabs_u3(startperiod:plotperiods),prabs_p3(startperiod:plotperiods),...
             shrmc*(rpxpq_u3(startperiod:plotperiods)+mgsnif_u3(startperiod:plotperiods)-gdp_u3(startperiod:plotperiods)),shrmc*(rpxpq_p3(startperiod:plotperiods)+mgsnif_p3(startperiod:plotperiods)-gdp_p3(startperiod:plotperiods)),....
             (rs_u3(startperiod:plotperiods)+(pibar/betap-1))*4,(rs_p3(startperiod:plotperiods)+(pibar/betap-1))*4];

figure2=makechart_neworder(titlelist,legendlist,figtitle,yaxislabels,line1,line2,line3);
subplot(4,2,1)
ylim([-8 1])
subplot(4,2,2)
ylim([-8 1])
subplot(4,2,3);
ylim([0 6])
subplot(4,2,4);
ylim([0 6])


subplot1=subplot(4,2,1);
legend1 = legend(subplot1,'show');
set(legend1,...
    'Position',[0.463583780018776 0.00823093376284885 0.105505394052914 0.0645658517998944]);

inset_axes = axes('Parent',figure2,...
    'Position',[0.286063569682152 0.815934065934066 0.10839445802771 0.052197802197802]);

selector =[1 2 3 4 5];

plot(gdp_u1(selector)./gdpf_u1(selector),'k-','LineWidth',1); hold on
plot(gdp_u2(selector)./gdpf_u2(selector),'b-.','linewidth',1); 
plot(gdp_u3(selector)./gdpf_u3(selector),'r--','linewidth',1); 

set(inset_axes,'Xtick',[1 2 3 4 5])

ylim([0 1])
xlim([1 5])
title('Ratio of Home to Foreign GDP')
xlabel('Quarters')


inset_axes = axes('Parent',figure2,...
    'Position',[0.740016299918499 0.821428571428572 0.101874490627547 0.0508241758241775]);
plot(gdp_p1(selector)./gdpf_p1(selector),'k-','LineWidth',1); hold on
plot(gdp_p2(selector)./gdpf_p2(selector),'b-.','linewidth',1); 
plot(gdp_p3(selector)./gdpf_p3(selector),'r--','linewidth',1); 

set(inset_axes,'Xtick',[1 2 3 4 5])
ylim([0 1])
xlim([1 5])
title('Ratio of Home to Foreign GDP')
xlabel('Quarters')

% Create textbox
annotation(figure2,'textbox',...
    [0.203933985330073 0.945054945054948 0.0851670741646292 0.032967032967033],...
    'String',{'ZlB Not Enforced'},...
    'LineStyle','none');

% Create textbox
annotation(figure2,'textbox',...
     [0.655066829665847 0.944285714285718 0.0696821515892421 0.032967032967033],...
    'String',{'ZlB Enforced'},...
    'LineStyle','none');