%% set inputs for solution below
%  The program produces responses to the shocks selected below under
%  irfshock. Paths for all the endogenous variables in the model selected
%  are produced. VariableName_difference holds the piece-wise linear solution for
%  VariableName.  VariableName_uncdifference holds the linear solution for
%  VariableName.


clear 
setpathdynare4

global M_ oo_

empty_var = [];
% list here any parameters to be overwritten -- leave only empty_var for all
% parameters at their default values specified in eggtrade_potential_param
% NB: make sure list matches whatever is specified in the baseline program
% runsim_eggtrade_potential_baseline.m

save param_overwrite empty_var

modnam = 'eggtrade_potential';
modnamstar = 'eggtrade_potential_zlb';

constraint = 'rs<-(pibar/betap-1)';
constraint_relax ='rs_notional>-(pibar/betap-1)';

% Pick innovation for IRFs
irfshock =char('errconshkp', 'erratpf');      % label for innovation for IRFs

maxiter = 15;
tol0 = 1e-8;



% assign parameter values
eggtrade_potential_param;
eggtrade_potential_comp_param;
 
% assign steady state values
eggtrade_potential_set_ss


% Solve nonlinear model

baseline_shocks = [ -0.12 0
                   zeros(0,2)] ;
shocks = [zeros(0,2)
    0 -0.01];

shockssequence = baseline_shocks;
nperiods = 30;



% Solve model, generate model IRFs
[zdatalinear zdatapiecewise zdatass oobase_ Mbase_  ] = ...
  solve_one_constraint(modnam,modnamstar,...
  constraint, constraint_relax,...
  shockssequence,irfshock,nperiods);

shockssequence = baseline_shocks+shocks;

[zdatalinear2 zdatapiecewise2 zdatass oobase_ Mbase_  ] = ...
  solve_one_constraint(modnam,modnamstar,...
  constraint, constraint_relax,...
  shockssequence,irfshock,nperiods);


% unpack the IRFs                          
for i=1:M_.endo_nbr
  eval([deblank(M_.endo_names(i,:)),'_u=zdatalinear(:,i);']);
  eval([deblank(M_.endo_names(i,:)),'_p=zdatapiecewise(:,i);']);
  eval([deblank(M_.endo_names(i,:)),'_ss=zdatass(i);']);
  eval([deblank(M_.endo_names(i,:)),'_u2=zdatalinear2(:,i)-zdatalinear(:,i);']);
  eval([deblank(M_.endo_names(i,:)),'_p2=zdatapiecewise2(:,i)-zdatapiecewise(:,i);']);
  
end


%% Modify to plot IRFs and decision rules

% plot of experiment
figtitle = '';
legendlist = char('Initial Conditions with ZLB enforced','Cumulative Responses with ZLB enforced');
titlelist = char('Home GDP','Home Policy Rate (level, AR)',...
                 'Home Absorption','Home Inflation (level, AR)',....
                 'Home Exports','Home Real Interest Rate (level, AR)',...
                 'Real Exchange Rate','Home Trade Balance (GDP share)');
             
yaxislabels = char('% dev. from s.s.','Percent',...
                   '% dev. from s.s.','Percent',...
                   '% dev. from s.s.','Percent',...
                   '% dev. from s.s.','% dev. from s.s.');
startperiod = 1;
plotperiods = nperiods;
               
makechart(titlelist,legendlist,figtitle,yaxislabels,...
100*[gdp_p(startperiod:plotperiods),(rs_p(startperiod:plotperiods)+(1/betap*pibar-1))*4,...
     prabs_p(startperiod:plotperiods),(dpq_p(startperiod:plotperiods)+pibar-1)*4,...
     mgsnif_p(startperiod:plotperiods),(rs1_p(startperiod:plotperiods)+(1/betap-1))*4,...
     rerpq_p(startperiod:plotperiods),ntby_p(startperiod:plotperiods)],...
100*[gdp_u(startperiod:plotperiods),(rs_u(startperiod:plotperiods)+(1/betap*pibar-1))*4,...
     prabs_u(startperiod:plotperiods),(dpq_u(startperiod:plotperiods)+pibar-1)*4,...
     mgsnif_u(startperiod:plotperiods),(rs1_u(startperiod:plotperiods)+(1/betap-1))*4,...
     rerpq_u(startperiod:plotperiods),ntby_u(startperiod:plotperiods)]);


% plot of experiment
figtitle = '';
legendlist = char('Shock with ZLB ','Shock without ZLB');
titlelist = char('Home GDP','Home Policy Rate (level, AR)',...
                 'Home Absorption','Home Inflation (level, AR)',....
                 'Home Exports','Home Real Interest Rate (level, AR)',...
                 'Real Exchange Rate','Home Trade Balance (GDP share)');
             
yaxislabels = char('% dev. from baseline','Percent',...
                   '% dev. from baseline','Percent',...
                   '% dev. from baseline','Percent',...
                   '% dev. from baseline','P.p. dev. from baseline');
startperiod = 1;
plotperiods = nperiods;
               
makechart_labels(titlelist,legendlist,figtitle,yaxislabels,...
100*[gdp_p2(startperiod:plotperiods),(rs_p2(startperiod:plotperiods)+rs_p(startperiod:plotperiods)+pibar/betap-1)*4,...
     prabs_p2(startperiod:plotperiods),(dpq_p2(startperiod:plotperiods)+dpq_p(startperiod:plotperiods)+pibar-1)*4,...
     mgsnif_p2(startperiod:plotperiods),(rs1_p2(startperiod:plotperiods)+rs1_p(startperiod:plotperiods)+1/betap-1)*4,...
     rerpq_p2(startperiod:plotperiods),ntby_p2(startperiod:plotperiods)],...
100*[gdp_u2(startperiod:plotperiods),(rs_u2(startperiod:plotperiods)+rs_u(startperiod:plotperiods)+pibar/betap-1)*4,...
     prabs_u2(startperiod:plotperiods),(dpq_u2(startperiod:plotperiods)+dpq_u(startperiod:plotperiods)+pibar-1)*4,...
     mgsnif_u2(startperiod:plotperiods),(rs1_u2(startperiod:plotperiods)+rs1_u2(startperiod:plotperiods)+1/betap-1)*4,...
     rerpq_u2(startperiod:plotperiods),ntby_u2(startperiod:plotperiods)]);
 
 
 
% plot of experiment
figtitle = '';
legendlist = char('Shock with ZLB ','Shock without ZLB');
titlelist = char('Home GDP','Foreign GDP',...
                 'Home Absorption','Home Policy Rate',...
                 'Home Exports','Home Inflation',....
                 'Real Exchange Rate','Home Real Interest Rate');
             
yaxislabels = char('% dev. from baseline','% dev. from baseline',...
                   '% dev. from baseline','P.p. dev. from baseline',...
                   '% dev. from baseline','P.p. dev. from baseline',...
                   '% dev. from baseline','P.p. dev. from baseline');
startperiod = 1;
plotperiods = nperiods;
               
line1 =100*[gdp_p2(startperiod:plotperiods),gdpf_p2(startperiod:plotperiods),...
     prabs_p2(startperiod:plotperiods),(rs_p2(startperiod:plotperiods))*4,...
     mgsnif_p2(startperiod:plotperiods),(dpq_p2(startperiod:plotperiods))*4,...
     rerpq_p2(startperiod:plotperiods),(rs1_p2(startperiod:plotperiods))*4];
line2 = 100*[gdp_u2(startperiod:plotperiods),gdpf_u2(startperiod:plotperiods),...
     prabs_u2(startperiod:plotperiods),(rs_u2(startperiod:plotperiods))*4,...
     mgsnif_u2(startperiod:plotperiods),(dpq_u2(startperiod:plotperiods))*4,...
     rerpq_u2(startperiod:plotperiods),(rs1_u2(startperiod:plotperiods))*4];
makechart(titlelist,legendlist,figtitle,yaxislabels,line1, line2)
 
 
